==> dasu_1.0.jar: edu/northwestern/dasu/measurement/AzureusSpeedTest.java <==
/**
 * Dasu Project
 *
 * File:         AzureusSpeedTest.java
 * RCS:          $Id: AzureusSpeedTest.java,v 1.2 2010/06/01 17:02:07 mas939 Exp $
 * Description:  AzureusSpeedTest class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:36:54 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;

import org.eclipse.swt.widgets.Text;
import org.gudy.azureus2.core3.internat.MessageText;
import org.gudy.azureus2.core3.util.Debug;
import org.gudy.azureus2.core3.util.DisplayFormatters;
import org.gudy.azureus2.ui.swt.speedtest.SpeedTestData;

import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduledTest;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduledTestListener;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduler;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTester;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTesterListener;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTesterResult;
import com.aelitis.azureus.core.networkmanager.admin.impl.NetworkAdminSpeedTestSchedulerImpl;

import edu.northwestern.dasu.drools.FactSpeedTestResult;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.Util;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The AzureusSpeedTest class ...
 */
public class AzureusSpeedTest implements NetworkAdminSpeedTestScheduledTestListener, NetworkAdminSpeedTesterListener{

	private boolean	test_running = false;
	int test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
	boolean encrypt_mode = false;
	TestType testType = TestType.AZUREUS_DL;

	private NetworkAdminSpeedTestScheduler nasts = 
		NetworkAdminSpeedTestSchedulerImpl.getInstance();
	private NetworkAdminSpeedTestScheduledTest scheduled_test;
		;
    long maxUploadTest, maxDownloadTest;
    boolean DEBUG = false;

	public void
	runTest(TestType testType)
	{
		this.testType = testType;
		
		if (testType.compareTo(TestType.AZUREUS_UL) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_UPLOAD_ONLY;
			encrypt_mode = false;
		}
		if (testType.compareTo(TestType.AZUREUS_UL_ENCRYPTION) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_UPLOAD_ONLY;
			encrypt_mode = true;
		}
		if (testType.compareTo(TestType.AZUREUS_DL) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
			encrypt_mode = false;
		}
		if (testType.compareTo(TestType.AZUREUS_DL_ENCRYPTION) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
			encrypt_mode = true;
		}
			
		test_running	= true;
		
		if ( nasts.getCurrentTest() !=  null ){
            if (DEBUG) 
            	System.out.println( MessageText.getString("SpeedTestWizard.test.panel.already.running") );
		}else{

			if (DEBUG)
				System.out.println( MessageText.getString("SpeedTestWizard.test.panel.already.running") );

			try{
                scheduled_test = nasts.scheduleTest( NetworkAdminSpeedTestScheduler.TEST_TYPE_BT );
                
                scheduled_test.getTester().setMode( test_mode );
                scheduled_test.getTester().setUseCrypto( encrypt_mode );

                scheduled_test.addListener( this );
				scheduled_test.getTester().addListener( this );
				
				maxUploadTest 	= scheduled_test.getMaxUpBytePerSec();
				maxDownloadTest = scheduled_test.getMaxDownBytePerSec();
				
				scheduled_test.start();
				
			}catch( Throwable e ){

                String requestNotAccepted = MessageText.getString("SpeedTestWizard.test.panel.not.accepted");
                if (DEBUG)
                	System.out.println( requestNotAccepted + Debug.getNestedExceptionMessage(e));
								
			}
		}//else
	}//runTest

	
	public void 
	stage(
		NetworkAdminSpeedTestScheduledTest 	test, 
		String 								step )
	{
		reportStage( step );
	}

	public void 
	complete(
		NetworkAdminSpeedTestScheduledTest test )
	{
	}
	
	
	public void 
	stage(
		NetworkAdminSpeedTester 	tester, 
		String 						step )
	{
		reportStage( step );
	}
	
	public void 
	complete(
		NetworkAdminSpeedTester			tester,
		NetworkAdminSpeedTesterResult 	result )
	{
        SpeedTestData.getInstance().setResult( result );
        reportComplete( result );
	}
	
	
	protected void 
	reportComplete(
		final NetworkAdminSpeedTesterResult 	result )
	{
		
    	  if ( result.hadError()){

    		  if (DEBUG) {
	              String testFailed = MessageText.getString("SpeedTestWizard.test.panel.testfailed");//Test failed
	              System.out.println(testFailed);
	              System.out.println(result.getLastError());
    		  }

    	  }else{
    		  
    		  FactSpeedTestResult speedResult = new FactSpeedTestResult(
    				  testType, result.getTestTime() - Util.dasuTimeOffset, result.getDownloadSpeed(),
    				  result.getUploadSpeed(), result.hadError(), result.getLastError(), encrypt_mode);

    		  updateSpeedTestResultQueue(speedResult);
    		  
    		  if (DEBUG) {
	              String uploadSpeedStr = MessageText.getString("GeneralView.label.uploadspeed");
	              String downlaodSpeedStr = MessageText.getString("GeneralView.label.downloadspeed");
	              System.out.println(uploadSpeedStr+" " + DisplayFormatters.formatByteCountToKiBEtcPerSec(result.getUploadSpeed()) + Text.DELIMITER);
	              System.out.println(downlaodSpeedStr+" " + DisplayFormatters.formatByteCountToKiBEtcPerSec(result.getDownloadSpeed()) + Text.DELIMITER);
    		  }

    	  }

    }

	protected void 
	reportStage(
		final String 						step )
	{

		if (DEBUG)
			System.out.println(step);
	}
	
	
	protected void updateSpeedTestResultQueue(FactSpeedTestResult result) {
			
		Long id = System.nanoTime();
		
		synchronized(AMCoordinatorV2.testResultTable) {
			AMCoordinatorV2.testResultTable.put(id, result);
		}
		
		synchronized(AMCoordinatorV2.events) {
			AMCoordinatorV2.events.add(
				new Pair<Long, EventType>(id, EventType.SPEEDTEST_RESULT));
			AMCoordinatorV2.events.notifyAll();
		}
	 }

}

==> dasu_2.02.jar: edu/northwestern/dasu/measurement/AzureusSpeedTest.java <==
/**
 * Dasu Project
 *
 * File:         AzureusSpeedTest.java
 * RCS:          $Id: AzureusSpeedTest.java,v 1.3 2010/11/01 15:37:00 mas939 Exp $
 * Description:  AzureusSpeedTest class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:36:54 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;

import org.eclipse.swt.widgets.Text;
import org.gudy.azureus2.core3.internat.MessageText;
import org.gudy.azureus2.core3.util.Debug;
import org.gudy.azureus2.core3.util.DisplayFormatters;
import org.gudy.azureus2.plugins.utils.UTTimer;
import org.gudy.azureus2.ui.swt.speedtest.SpeedTestData;

import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduledTest;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduledTestListener;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTestScheduler;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTester;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTesterListener;
import com.aelitis.azureus.core.networkmanager.admin.NetworkAdminSpeedTesterResult;
import com.aelitis.azureus.core.networkmanager.admin.impl.NetworkAdminSpeedTestSchedulerImpl;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.drools.FactSpeedTestResult;
import edu.northwestern.dasu.stats.Statistics;
import edu.northwestern.dasu.util.Pair;
import edu.northwestern.dasu.util.Util;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The AzureusSpeedTest class ...
 */
public class AzureusSpeedTest implements NetworkAdminSpeedTestScheduledTestListener, NetworkAdminSpeedTesterListener{

	private boolean	test_running = false;
	int test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
	boolean encrypt_mode = false;
	TestType testType = TestType.AZUREUS_DL;

	private NetworkAdminSpeedTestScheduler nasts = 
		NetworkAdminSpeedTestSchedulerImpl.getInstance();
	private NetworkAdminSpeedTestScheduledTest scheduled_test;
		;
    long maxUploadTest, maxDownloadTest;
    boolean DEBUG = true;

    /*netstat*/
    UTTimer netstatBWutTimer;
    NetstatBanwidthPerformer netstatBWPerf;
    Long timeBefore;
    
	public void
	runTest(TestType testType)
	{
		this.testType = testType;
		
		if (testType.compareTo(TestType.AZUREUS_UL) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_UPLOAD_ONLY;
			encrypt_mode = false;
		}
		if (testType.compareTo(TestType.AZUREUS_UL_ENCRYPTION) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_UPLOAD_ONLY;
			encrypt_mode = true;
		}
		if (testType.compareTo(TestType.AZUREUS_DL) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
			encrypt_mode = false;
		}
		if (testType.compareTo(TestType.AZUREUS_DL_ENCRYPTION) == 0) {
			test_mode = NetworkAdminSpeedTester.TEST_TYPE_DOWNLOAD_ONLY;
			encrypt_mode = true;
		}
			
		test_running	= true;
		
		if ( nasts.getCurrentTest() !=  null ){
            if (DEBUG) 
            	System.out.println( MessageText.getString("SpeedTestWizard.test.panel.already.running") );
		}else{

			if (DEBUG)
				System.out.println( MessageText.getString("SpeedTestWizard.test.panel.already.running") );

			
			/*** netstat ***/
			
			netstatBWutTimer = Main.getPluginInterface().getUtilities().createTimer("ndt netstat", true);
	    	netstatBWPerf = new NetstatBanwidthPerformer(Main.getPluginInterface(), MainGeneric.getInterfaceName());
	    	netstatBWutTimer.addPeriodicEvent(1000, netstatBWPerf);
	    	timeBefore = NetstatBWStats.getInstance().getMostRecent().timeRecorded;
	    	
	    	/*** netstat ***/
			
			try{
                scheduled_test = nasts.scheduleTest( NetworkAdminSpeedTestScheduler.TEST_TYPE_BT );
                
                scheduled_test.getTester().setMode( test_mode );
                scheduled_test.getTester().setUseCrypto( encrypt_mode );

                scheduled_test.addListener( this );
				scheduled_test.getTester().addListener( this );
				
				maxUploadTest 	= scheduled_test.getMaxUpBytePerSec();
				maxDownloadTest = scheduled_test.getMaxDownBytePerSec();
								
				scheduled_test.start();
				
			}catch( Throwable e ){

                String requestNotAccepted = MessageText.getString("SpeedTestWizard.test.panel.not.accepted");
                if (DEBUG)
                	System.out.println( requestNotAccepted + Debug.getNestedExceptionMessage(e));

    	    	/*
    	    	 * sleep for five seconds after ndt finishes
    	    	 * to ensure timer already fired at least once
    	    	 * before trying to destroy it 
    	    	 * in case ndt measurement fails
    	    	 */

    	    	try {
    				Thread.sleep(5000);
    			} catch (InterruptedException e1) {
    				e1.printStackTrace();
    			}
                
                if (netstatBWutTimer != null)
                	netstatBWutTimer.destroy();
                
                if (netstatBWPerf != null)
                	netstatBWPerf.cancelTimer();
			
			}
						
		}//else
	}//runTest

	
	public void 
	stage(
		NetworkAdminSpeedTestScheduledTest 	test, 
		String 								step )
	{
		reportStage( step );
	}

	public void 
	complete(
		NetworkAdminSpeedTestScheduledTest test )
	{
	}
	
	
	public void 
	stage(
		NetworkAdminSpeedTester 	tester, 
		String 						step )
	{
		reportStage( step );
	}
	
	public void 
	complete(
		NetworkAdminSpeedTester			tester,
		NetworkAdminSpeedTesterResult 	result )
	{
        SpeedTestData.getInstance().setResult( result );
        reportComplete( result );
	}
	
	
	protected void 
	reportComplete(
		final NetworkAdminSpeedTesterResult 	result )
	{
		
		  try {
			Thread.sleep(5000);
		  } catch (InterruptedException e) {
			e.printStackTrace();
		  }

		  if (netstatBWutTimer != null)
			netstatBWutTimer.destroy();
		  if (netstatBWPerf != null)
			netstatBWPerf.cancelTimer();
		
		  Long timeAfter = NetstatBWStats.getInstance().getMostRecent().timeRecorded;
		  
		  Double c2sRateNetstat = (double) NetstatBWStats.getInstance().getPercentileUploadBetween(timeBefore, timeAfter, 95)/1000;
		  Double s2cRateNetstat = (double) NetstatBWStats.getInstance().getPercentileDownloadBetween(timeBefore, timeAfter, 95)/1000;

    			
    	  if ( result.hadError()){

    		  if (DEBUG) {
	              String testFailed = MessageText.getString("SpeedTestWizard.test.panel.testfailed");//Test failed
	              System.out.println(testFailed);
	              System.out.println(result.getLastError());
    		  }

    	  }else{

    		  FactSpeedTestResult speedResult = new FactSpeedTestResult(
    				  testType, result.getTestTime() - Util.dasuTimeOffset, result.getDownloadSpeed()/1000,
    				  result.getUploadSpeed()/1000, result.hadError(), result.getLastError(), encrypt_mode,
    				  s2cRateNetstat.intValue(), c2sRateNetstat.intValue());

    		  updateSpeedTestResultQueue(speedResult);
    		  
    		  if (DEBUG) {
	              String uploadSpeedStr = MessageText.getString("GeneralView.label.uploadspeed");
	              String downlaodSpeedStr = MessageText.getString("GeneralView.label.downloadspeed");
	              System.out.println(uploadSpeedStr+" " + DisplayFormatters.formatByteCountToKiBEtcPerSec(result.getUploadSpeed()) + Text.DELIMITER);
	              System.out.println(downlaodSpeedStr+" " + DisplayFormatters.formatByteCountToKiBEtcPerSec(result.getDownloadSpeed()) + Text.DELIMITER);

	              System.out.println("\n");
    			  System.out.println("SpeedTest received:" + speedResult.getDownloadSpeed());
    			  System.out.println("Netstat 95th received:" + speedResult.getDownloadSpeedNetstat());
    			  System.out.println("Netstat max received: " + NetstatBWStats.getInstance().getFastestDownloadBetween(timeBefore, timeAfter)/1000);
    			  System.out.println("SpeedTest sent:" + speedResult.getUploadSpeed());
    			  System.out.println("Netstat 95th sent:" + speedResult.getUploadSpeedNetstat());
    			  System.out.println("Netstat max sent: " + NetstatBWStats.getInstance().getFastestUploadBetween(timeBefore, timeAfter)/1000);
    			  System.out.println("Time max Download: " + NetstatBWStats.getInstance().getFastestUploadBetween(timeBefore, timeAfter));
    			  System.out.println("\n\nMARIO AFTER: " + NetstatBWStats.getInstance());
    			
    		  }
    		  
    		  
    	  }

    }

	protected void 
	reportStage(
		final String 						step )
	{

		if (DEBUG)
			System.out.println(step);
	}
	
	
	protected void updateSpeedTestResultQueue(FactSpeedTestResult result) {
			
		Long id = System.nanoTime();
		
		synchronized(AMCoordinatorV2.testResultTable) {
			AMCoordinatorV2.testResultTable.put(id, result);
		}
		
		synchronized(AMCoordinatorV2.events) {
			AMCoordinatorV2.events.add(
				new Pair<Long, EventType>(id, EventType.SPEEDTEST_RESULT));
			AMCoordinatorV2.events.notifyAll();
		}
	 }

}
